@@ -3,7 +3,6 @@ from os import path
 import secrets
 import string
 from datetime import date
-from dateutil.relativedelta import relativedelta
 
 
 def remote_bat_file(filename):
@@ -14,7 +13,7 @@ def remote_bat_file(filename):
 
 def generate_inmemory_file(file_content):
     fl = BytesIO()
-    fl.write(file_content.encode())
+    fl.write(file_content)
     fl.seek(0)
     return fl
 
@@ -23,18 +22,17 @@ def _generate_random_password():
     return ''.join(secrets.choice(alphabet) for i in range(12))
 
 
-def generate_file_data(n, raspberry, ovpn_pass):
+def generate_file_data(connections, expiry_date):
     ids = []
     exe_passes = []
     ovpn_passes = []
     expiry_dates = []
     expiry_times = []
-    expiry_date = date.today() + relativedelta(months=+6)
 
-    for i in range(1, n+1):
-        ids.append(f'{raspberry}-{i}')
-        exe_passes.append(_generate_random_password())
-        ovpn_passes.append(ovpn_pass)
+    for c in connections:
+        ids.append(c['canper_id'])
+        exe_passes.append(c['exe_contraseña'])
+        ovpn_passes.append(c['raspberry']['ovpn_contraseña'])
         expiry_dates.append(expiry_date.strftime('%d-%m-%Y'))
         expiry_times.append('23:59')
 
